@@ -1,6 +1,6 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
+ * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
  * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ class U2ALGORITHM_EXPORT MSADistanceAlgorithmFactorySimilarity: public MSADistan
 public:
     MSADistanceAlgorithmFactorySimilarity(QObject* p = NULL);
 
-    virtual MSADistanceAlgorithm* createAlgorithm(const MAlignment& ma, QObject* parent);
+    virtual MSADistanceAlgorithm* createAlgorithm(const MultipleSequenceAlignment& ma, QObject* parent);
 
     virtual QString getDescription() const;
 
@@ -51,7 +51,7 @@ public:
 class U2ALGORITHM_EXPORT MSADistanceAlgorithmSimilarity : public MSADistanceAlgorithm {
     Q_OBJECT
 public:
-    MSADistanceAlgorithmSimilarity(MSADistanceAlgorithmFactorySimilarity* f, const MAlignment& ma)
+    MSADistanceAlgorithmSimilarity(MSADistanceAlgorithmFactorySimilarity* f, const MultipleSequenceAlignment& ma)
         : MSADistanceAlgorithm(f, ma){isSimilarity = true;}
 
     virtual void run();
