@@ -1,7 +1,7 @@
 /**
  * UGENE - Integrated Bioinformatics Tools.
- * Copyright (C) 2008-2013 UniPro <ugene@unipro.ru>
- * http://ugene.unipro.ru
+ * Copyright (C) 2008-2019 UniPro <ugene@unipro.ru>
+ * http://ugene.net
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,11 +26,20 @@
 
 namespace U2 {
 
-class U2CORE_EXPORT GObjectRelationRole {
+enum GObjectRelationRole {
+    ObjectRole_Sequence = 1,
+    ObjectRole_AnnotationTable,
+    ObjectRole_PhylogeneticTree,
+    ObjectRole_ReferenceSequence
+};
+
+/**
+ * The class for supporting of old relation roles
+ */
+class GObjectRelationRoleCompatibility {
 public:
-    static const QString SEQUENCE;
-    static const QString ANNOTATION_TABLE;
-    static const QString PHYLOGENETIC_TREE;
+    static QString toString(GObjectRelationRole role);
+    static GObjectRelationRole fromString(const QString &str);
 };
 
 }//namespace
